==> script.video.nfl.gamepass-2022.05.14.zip: script.video.nfl.gamepass/README.md <==
# NOTE #

This addon supports NFL Game Pass, which is a merger of previous
services called Game Pass Europe and Game Pass International.
NFL Game Pass is available in these countries:
https://support.nflgamepass.com/hc/en-gb/articles/360004691153

# NFL Game Pass Kodi Plugin #

Before reading any further, please understand that this addon is unofficial and
is not endorsed or supported by the NFL in any way. Not all features are
supported (see below) and it should be forever regarded as a beta release. It
may crash, spay your puppy, and/or cause your oven to not heat to 400°F
properly.

If you're interested in helping out, just drop us an email or send a pull
request. Patches and (constructive) input are always welcome.

## How to Install ##

This addon requires Kodi Matrix or later. Please ensure that Inputstream Adaptive
is installed and enabled (Addon: inputstream.adaptive).

### Kodi Repository ###

This addon is available from the official Kodi repository, and is the
recommended method of installing this addon.

### From GitHub ###

If you install from GitHub (either by download the .zip archive or using
``git``), you will need to install some dependencies:

 * Requests >= 2.22.0+matrix.1 (https://mirrors.kodi.tv/addons/matrix/script.module.requests/)
 * m3u8 >= 0.5.4+matrix.2 (https://mirrors.kodi.tv/addons/matrix/script.module.m3u8/)
   * which needs iso8601 (https://mirrors.kodi.tv/addons/matrix/script.module.iso8601/)
 * inputstream.adaptive >= 19.0 (https://kodi.tv/addons/matrix/inputstream.adaptive)

## What is NFL Game Pass? ##

NFL Game Pass is a service which allows those with subscriptions to watch NFL
games. Live games, archives of old games, NFL TV shows, NFL Network, and coaches
tape (22 man view) are available. Overall, it is a sweet service offered by the
NFL for those of us who must have our American Football fix.

### What is Game Pass Europe? ###

NFL Game Pass Europe was the original NFL Game Pass service supported by this addon.
NFL Game Pass Europe later was merged with NFL Game Pass International and became
NFL Game Pass.

### What is Game Pass International? ###

Game Pass International was an older service providing access to NFL offerings
outside of US and Europe. Game Pass International was merged with NFL Game Pass
Europe and became NFL Game Pass.

### What is NFL Game Pass Domestic? ###

The "original" NFL Game Pass was renamed to NFL Game Pass Domestic and was only
available in US. The NFL retired NFL Game Pass Domestic in 2022 and replaced it
with their own streaming solution called NFL+. This addon is not compatible with
NFL+.

## Supported Features ##

We used to maintain a list of features that were known working, broken, etc.
With the split in services and the yearly breakage, the list was always out of
date.

The new situation is: everything basically works. If not, there's an issue for
it. If there's no issue, please open one, attach a log, and (if you want fame
and fortune) create a PR with the fix.

## Release Names ##

Want a release to be named after your player/coach/defense of choice? Contribute
to the project in some way (code, art, debugging, beer, brazen — yet effective —
flattery, etc), and we'll gladly name a future release after them.

==> script.video.nfl.gamepass-2023.07.05.zip: script.video.nfl.gamepass/README.md <==
# All good things come to an end

After retiring NFL Gamepass Domestic in 2022, the NFL decided to shutdown the international Gamepass service
as well in 2023, rendering this add-on obsolete.

Outside of the States, DAZN is the new home for the NFL Gamepass service. You can watch the games with a DAZN
account and an NFL Gamepass subscription.

The good news is that there is a DAZN add-on available for Kodi, so it is still possible to watch NFL games on our
most favorite media center.

---

# NOTE #

This addon supports NFL Game Pass, which is a merger of previous
services called Game Pass Europe and Game Pass International.
NFL Game Pass is available in these countries:
https://support.nflgamepass.com/hc/en-gb/articles/360004691153

# NFL Game Pass Kodi Plugin #

Before reading any further, please understand that this addon is unofficial and
is not endorsed or supported by the NFL in any way. Not all features are
supported (see below) and it should be forever regarded as a beta release. It
may crash, spay your puppy, and/or cause your oven to not heat to 400°F
properly.

If you're interested in helping out, just drop us an email or send a pull
request. Patches and (constructive) input are always welcome.

## How to Install ##

This addon requires Kodi Matrix or later. Please ensure that Inputstream Adaptive
is installed and enabled (Addon: inputstream.adaptive).

### Kodi Repository ###

This addon is available from the official Kodi repository, and is the
recommended method of installing this addon.

### From GitHub ###

If you install from GitHub (either by download the .zip archive or using
``git``), you will need to install some dependencies:

 * Requests >= 2.22.0+matrix.1 (https://mirrors.kodi.tv/addons/matrix/script.module.requests/)
 * m3u8 >= 0.5.4+matrix.2 (https://mirrors.kodi.tv/addons/matrix/script.module.m3u8/)
   * which needs iso8601 (https://mirrors.kodi.tv/addons/matrix/script.module.iso8601/)
 * inputstream.adaptive >= 19.0 (https://kodi.tv/addons/matrix/inputstream.adaptive)

## What is NFL Game Pass? ##

NFL Game Pass is a service which allows those with subscriptions to watch NFL
games. Live games, archives of old games, NFL TV shows, NFL Network, and coaches
tape (22 man view) are available. Overall, it is a sweet service offered by the
NFL for those of us who must have our American Football fix.

### What is Game Pass Europe? ###

NFL Game Pass Europe was the original NFL Game Pass service supported by this addon.
NFL Game Pass Europe later was merged with NFL Game Pass International and became
NFL Game Pass.

### What is Game Pass International? ###

Game Pass International was an older service providing access to NFL offerings
outside of US and Europe. Game Pass International was merged with NFL Game Pass
Europe and became NFL Game Pass.

### What is NFL Game Pass Domestic? ###

The "original" NFL Game Pass was renamed to NFL Game Pass Domestic and was only
available in US. The NFL retired NFL Game Pass Domestic in 2022 and replaced it
with their own streaming solution called NFL+. This addon is not compatible with
NFL+.

## Supported Features ##

We used to maintain a list of features that were known working, broken, etc.
With the split in services and the yearly breakage, the list was always out of
date.

The new situation is: everything basically works. If not, there's an issue for
it. If there's no issue, please open one, attach a log, and (if you want fame
and fortune) create a PR with the fix.

## Release Names ##

Want a release to be named after your player/coach/defense of choice? Contribute
to the project in some way (code, art, debugging, beer, brazen — yet effective —
flattery, etc), and we'll gladly name a future release after them.
